@@ -235,10 +235,7 @@ def delhubgroup(groupName):
 def addhubgroup(db, groupName, groupDescription):
 
 	gidNumber = _insert_jos_xgroups(db, groupName, groupDescription)
-	return gidNumber
 
-	
-def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, loginShell, nocreatehome, homeDir, createGroup, skipldap):
 	# grab config options
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
@@ -276,13 +273,12 @@ def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidN
 		print procStdOut
 		if rc:
 			print procStdErr
-
-	
-	# set ownerships
-	rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["chown", username + "." + username, homeDir])
-	print procStdOut
-	if rc:
-		print procStdErr
+		
+		# set ownerships
+		rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["chown", username + "." + username, homeDir])
+		print procStdOut
+		if rc:
+			print procStdErr
 
 	
 	if not skipldap:
